<?php

class bt_bb_card extends BT_BB_Element {

	function handle_shortcode( $atts, $content ) {
		extract( shortcode_atts( apply_filters( 'bt_bb_extract_atts', array(
			'padding'                		=> '',
			'background_image'				=> '',
			'image_position'				=> '',
			'shape'							=> '',
			'color_scheme' 					=> '',
			'background_color'   			=> '',
			'border'   						=> '',
			'url'    						=> '',
			'target' 						=> ''
		) ), $atts, $this->shortcode ) );

		$class = array( $this->shortcode );
		$data_override_class = array();

		if ( $el_class != '' ) {
			$class[] = $el_class;
		}

		$id_attr = '';
		if ( $el_id != '' ) {
			$id_attr = ' ' . 'id="' . esc_attr( $el_id ) . '"';
		}

		$size = '';
		if ( $background_image != '' && is_numeric( $background_image ) && $image_position == '' ) {
			$post_image = get_post( $background_image );
			if ( $post_image == '' ) return;
			$size = " boldthemes_large_rectangle";
			$background_image = wp_get_attachment_image_src( $background_image, $size );
			$background_image = $background_image[0];
			
			$class[] = "btHasBgImage";
			$el_style .= 'background-image: url(' . $background_image . ')';
		}

		if ( $background_color != '' ) {
			$el_style = $el_style . 'background-color:' . $background_color . ';';
		}

		$this->responsive_data_override_class(
			$class, $data_override_class,
			array(
				'prefix' => $this->prefix,
				'param' => 'padding',
				'value' => $padding
			)
		);

		if ( $url != '' ) {
			$class[] = 'btWithLink';
		}

		

		if ( $shape != '' ) {
			$class[] = $this->prefix . 'shape' . '_' . $shape;
		}

		if ( $border != '' ) {
			$class[] = $this->prefix . 'border' . '_' . $border;
		}

		if ( $image_position != '' ) {
			$class[] = $this->prefix . 'image_position' . '_' . $image_position;
		}

		$color_scheme_id = NULL;
		if ( is_numeric ( $color_scheme ) ) {
			$color_scheme_id = $color_scheme;
		} else if ( $color_scheme != '' ) {
			$color_scheme_id = bt_bb_get_color_scheme_id( $color_scheme );
		}
		$color_scheme_colors = bt_bb_get_color_scheme_colors_by_id( $color_scheme_id - 1 );
		if ( $color_scheme_colors ) $el_style .= '; --primary-color:' . $color_scheme_colors[0] . '; --secondary-color:' . $color_scheme_colors[1] . ';';
		if ( $color_scheme != '' ) $class[] = $this->prefix . 'color_scheme_' .  $color_scheme_id;


		$style_attr = '';
		if ( $el_style != '' ) {
			$style_attr = ' ' . 'style="' . esc_attr( $el_style ) . '"';
		}

		$content = do_shortcode( $content );
		$link = bt_bb_get_permalink_by_slug( $url );

		$class = apply_filters( $this->shortcode . '_class', $class, $atts );		
		$class_attr = implode( ' ', $class );
		
		if ( $el_class != '' ) {
			$class_attr = $class_attr . ' ' . $el_class;
		}

		
		$output = '<div' . $id_attr . ' class="' . esc_attr( $class_attr ) . '"' . $style_attr . ' data-bt-override-class="' . htmlspecialchars( json_encode( $data_override_class, JSON_FORCE_OBJECT ), ENT_QUOTES, 'UTF-8' ) . '">';

			// LINK
			if ( $link != '' ) {
				$target_attr = ' target="_self" ';
				if ( $target != '' ) {
					$target_attr = ' ' . 'target="' . esc_attr( $target ) . '"';
				}
				$output .= '<a href="' . esc_url( $link ) . '" ' . $target_attr . ' class="btCardLink"></a>';
			}
			
			// CONTENT
			if ( $content != '' ) $output .= '<div class="' . esc_attr( $this->shortcode . '_content' ) . '">' . ( $content ) . '</div>';
					
			
			// IMAGE POSITION - ROTATE
			if ( $image_position == 'rotate' ) {
				$img = wp_get_attachment_image_src( $background_image, $size = 'full' );
				$img_src = isset($img[0]) ? $img[0] : '';
				if ( $img_src != '' ) {
					$output .= '<div class="' . esc_attr( $this->shortcode . '_image' ) . '"><img src="' . esc_url( $img_src ) . '"></div>';
				}
			}

		$output .= '</div>';


		$output = apply_filters( 'bt_bb_general_output', $output, $atts );
		$output = apply_filters( $this->shortcode . '_output', $output, $atts );

		return $output;

	}

	function map_shortcode() {

		$color_scheme_arr = bt_bb_get_color_scheme_param_array();

		
		bt_bb_map( $this->shortcode, array( 'name' => esc_html__( 'Card', 'bambino' ), 'description' => esc_html__( 'Card with icon, title and text', 'bambino' ), 'container' => 'vertical', 'accept' => array( 'bt_bb_headline' => true, 'bt_bb_button' => true, 'bt_bb_icon' => true, 'bt_bb_text' => true, 'bt_bb_card_inner' => true, 'bt_bb_separator' => true ), 'icon' => $this->prefix_backend . 'icon' . '_' . $this->shortcode,
			'params' => array(
				array( 'param_name' => 'background_image', 'type' => 'attach_image', 'heading' => esc_html__( 'Image', 'bambino' ), 'preview' => true ),
				array( 'param_name' => 'padding', 'type' => 'dropdown', 'heading' => esc_html__( 'Inner padding', 'bambino' ), 'preview' => true, 'responsive_override' => true,
					'value' => array(
						esc_html__( 'Default', 'bambino' ) 		=> 'none',
						esc_html__( 'Normal', 'bambino' ) 		=> 'normal',
						esc_html__( 'Double', 'bambino' ) 		=> 'double',
						esc_html__( 'Text Indent', 'bambino' ) 	=> 'text_indent',
						esc_html__( '0px', 'bambino' ) 			=> '0',
						esc_html__( '5px', 'bambino' ) 			=> '5',
						esc_html__( '10px', 'bambino' ) 		=> '10',
						esc_html__( '15px', 'bambino' ) 		=> '15',
						esc_html__( '20px', 'bambino' ) 		=> '20',
						esc_html__( '25px', 'bambino' ) 		=> '25',
						esc_html__( '30px', 'bambino' ) 		=> '30',
						esc_html__( '35px', 'bambino' ) 		=> '35',
						esc_html__( '40px', 'bambino' ) 		=> '40',
						esc_html__( '45px', 'bambino' ) 		=> '45',
						esc_html__( '50px', 'bambino' ) 		=> '50',
						esc_html__( '55px', 'bambino' ) 		=> '55',
						esc_html__( '60px', 'bambino' ) 		=> '60',
						esc_html__( '65px', 'bambino' ) 		=> '65',
						esc_html__( '70px', 'bambino' ) 		=> '70',
						esc_html__( '75px', 'bambino' ) 		=> '75',
						esc_html__( '80px', 'bambino' ) 		=> '80',
						esc_html__( '85px', 'bambino' ) 		=> '85',
						esc_html__( '90px', 'bambino' ) 		=> '90',
						esc_html__( '95px', 'bambino' ) 		=> '95',
						esc_html__( '100px', 'bambino' ) 		=> '100'
					)
				),
				array( 'param_name' => 'color_scheme', 'type' => 'dropdown', 'heading' => esc_html__( 'Color scheme', 'bambino' ),  'value' => $color_scheme_arr, 'preview' => true ),
				array( 'param_name' => 'background_color', 'preview' => true, 'type' => 'colorpicker', 'heading' => esc_html__( 'Background color', 'bambino' ) ),
				array( 'param_name' => 'image_position', 'type' => 'dropdown', 'heading' => esc_html__( 'Image position', 'bambino' ),
					'value' => array(
						esc_html__( 'Background', 'bambino' ) 	=> '',
						esc_html__( 'Rotate', 'bambino' ) 		=> 'rotate'
				) ),
				array( 'param_name' => 'shape', 'default' => '', 'type' => 'dropdown', 'heading' => esc_html__( 'Shape', 'bambino' ), 
					'value' => array(
						esc_html__( 'Inherit', 'bambino' ) 			=> '',
						esc_html__( 'Square', 'bambino' ) 			=> 'square',
						esc_html__( 'Soft rounded', 'bambino' )		=> 'soft-rounded',
						esc_html__( 'Hard rounded', 'bambino' )		=> 'hard-rounded'
					)
				),
				array( 'param_name' => 'border', 'default' => '', 'type' => 'dropdown', 'heading' => esc_html__( 'Card border', 'bambino' ), 
					'value' => array(
						esc_html__( 'No', 'bambino' ) 								=> '',
						esc_html__( 'Show (accent color, 1px)', 'bambino' ) 		=> 'accent'
					)
				),

				array( 'param_name' => 'url', 'type' => 'link', 'heading' => esc_html__( 'URL', 'bambino' ), 'preview' => true, 'description' => esc_html__( 'Enter full or local URL (e.g. https://www.bold-themes.com or /pages/about-us), post slug (e.g. about-us), #lightbox to open current image in full size or search for existing content.', 'bambino' ), 'group' => esc_html__( 'URL', 'bambino' ) ),
				array( 'param_name' => 'target', 'type' => 'dropdown', 'group' => esc_html__( 'URL', 'bambino' ), 'heading' => esc_html__( 'Target', 'bambino' ),
					'value' => array(
						esc_html__( 'Self (open in same tab)', 'bambino' ) 	=> '_self',
						esc_html__( 'Blank (open in new tab)', 'bambino' ) 	=> '_blank',
					)
				),
				)
			)
		);
	}
}