<?php

class bt_bb_timetable extends BT_BB_Element {

	function handle_shortcode( $atts, $content ) {
		extract( shortcode_atts( apply_filters( 'bt_bb_extract_atts', array(
			'title'					=> '',
			'supertitle'			=> '',
			'content'				=> '',
			'html_tag'      		=> 'h3',
			'color_scheme' 			=> '',
			'style' 				=> ''
		) ), $atts, $this->shortcode ) );

		$class = array( $this->shortcode );

		if ( $el_class != '' ) {
			$class[] = $el_class;
		}

		if ( $style != '' ) {
			$class[] = $this->prefix . 'style' . '_' . $style;
		}

		$id_attr = '';
		if ( $el_id != '' ) {
			$id_attr = ' ' . 'id="' . esc_attr( $el_id ) . '"';
		}
		
		$color_scheme_id = NULL;
		if ( is_numeric ( $color_scheme ) ) {
			$color_scheme_id = $color_scheme;
		} else if ( $color_scheme != '' ) {
			$color_scheme_id = bt_bb_get_color_scheme_id( $color_scheme );
		}
		$color_scheme_colors = bt_bb_get_color_scheme_colors_by_id( $color_scheme_id - 1 );
		if ( $color_scheme_colors ) $el_style .= '; --primary-color:' . $color_scheme_colors[0] . '; --secondary-color:' . $color_scheme_colors[1] . ';';
		if ( $color_scheme != '' ) $class[] = $this->prefix . 'color_scheme_' .  $color_scheme_id;


		$style_attr = '';
		if ( $el_style != '' ) {
			$style_attr = ' ' . 'style="' . esc_attr( $el_style ) . '"';
		}


		$output_inner = '';
		$items_arr = preg_split( '/$\R?^/m', $content );
		if ( count( $items_arr ) > 0 ) {
			foreach ( $items_arr as $item ) { 
				$item = preg_replace('~[\r\n]+~', '', $item);
				if ( $item == '' ) break;
				$item_arr = explode( ';', $item );
				if ( count( $item_arr ) < 2 ) break;
				$bt_extra_row_class = '';
				$bt_extra_data = '';
				if ( isset( $item_arr[2] ) ) {
					$bt_extra_data = ' data-day="' . esc_attr( $item_arr[2] ) . '"';
					if ( strtolower ( date('D') ) ==  strtolower ( $item_arr[2] )) $bt_extra_row_class = ' btToday';	
				}
				$output_inner .= '<div class="' . esc_attr( $this->shortcode . '_inner_row' ) . $bt_extra_row_class . '"' . $bt_extra_data . '>';
					$output_inner .= '<div class="' . esc_attr( $this->shortcode . '_day' ) . '">';
						$output_inner .= '<span>' . $item_arr[0] . '</span>';
						if ( isset ($item_arr[3]) && $item_arr[3] != '' )  $output_inner .= '<span class="' . esc_attr( $this->shortcode . '_inner_desc' ) . '">' . $item_arr[3] . '</span>';
					$output_inner .= '</div>';
					$output_inner .= '<div class="' . esc_attr( $this->shortcode . '_time' ) . '">';
						$output_inner .= '<span>' . $item_arr[1] . '</span>';
						if ( isset ( $item_arr[4] ) && $item_arr[4] != '' ) $output_inner .= '<span class="' . esc_attr( $this->shortcode . '_inner_location' ) . '">' . $item_arr[4] . '</span>';
					$output_inner .= '</div>';
				$output_inner .= '</div>';				
			} 
		}
		$output = '<div class="' . esc_attr( $this->shortcode . '_title_flex' ) . '">';
			$output .= do_shortcode('[bt_bb_headline headline="' . esc_attr( $title ) . '" html_tag="'. esc_attr( $html_tag ) .'" superheadline="' . esc_attr( $supertitle ) . '" size="medium" ignore_fe_editor="true"]');
		$output .= '</div>';

		$output .= '<div class="' . esc_attr( $this->shortcode . '_content' ) . '">';
			$output .= $output_inner;
		$output .= '</div>';

		$output = '<div' . $id_attr . ' class="' . implode( ' ', $class ) . '"' . $style_attr . '>' . $output . '</div>';
		
		$output = apply_filters( 'bt_bb_general_output', $output, $atts );
		$output = apply_filters( $this->shortcode . '_output', $output, $atts );

		return $output;
	}	

	function map_shortcode() {

		$color_scheme_arr = bt_bb_get_color_scheme_param_array();

		bt_bb_map( $this->shortcode, array( 'name' => esc_html__( 'Timetable', 'bambino' ), 'description' => esc_html__( 'Timetable list', 'bambino' ), 'icon' => $this->prefix_backend . 'icon' . '_' . $this->shortcode,
			'params' => array(
				array( 'param_name' => 'supertitle', 'type' => 'textfield', 'heading' => esc_html__( 'Supertitle', 'bambino' ) ),
				array( 'param_name' => 'title', 'type' => 'textfield', 'heading' => esc_html__( 'Title', 'bambino' ) ),
				array( 'param_name' => 'content', 'type' => 'textarea', 'heading' => esc_html__( 'Timetable', 'bambino' ), 'description' => esc_html__( 'day;time;day abbreviation (e.x. MON for monday);description;location', 'bambino' )
				),
				array( 'param_name' => 'html_tag', 'type' => 'dropdown', 'default' => 'h3', 'heading' => esc_html__( 'Title HTML tag', 'bambino' ),
					'value' => array(
						esc_html__( 'h1', 'bambino' ) 				=> 'h1',
						esc_html__( 'h2', 'bambino' )	 			=> 'h2',
						esc_html__( 'h3', 'bambino' ) 				=> 'h3',
						esc_html__( 'h4', 'bambino' ) 				=> 'h4',
						esc_html__( 'h5', 'bambino' ) 				=> 'h5',
						esc_html__( 'h6', 'bambino' ) 				=> 'h6'
				) ),
				array( 'param_name' => 'color_scheme', 'type' => 'dropdown', 'heading' => esc_html__( 'Color scheme', 'bambino' ), 'group' => esc_html__( 'Design', 'bambino' ), 'value' => $color_scheme_arr, 'preview' => true ),
				array( 'param_name' => 'style', 'type' => 'dropdown', 'default' => '', 'heading' => esc_html__( 'Style', 'bambino' ), 'group' => esc_html__( 'Design', 'bambino' ),
					'value' => array(
						esc_html__( 'Filled', 'bambino' ) 			=> '',
						esc_html__( 'Outline', 'bambino' )	 		=> 'outline'
				) ),
			))
		);
	}
}