<?php

// Register action/filter callbacks

add_action( 'after_setup_theme', 'bambino_register_menus' );
add_action( 'wp_enqueue_scripts', 'bambino_enqueue_scripts_styles' );
add_action( 'tgmpa_register', 'bambino_register_plugins' );
add_action( 'wp_enqueue_scripts', 'bambino_load_fonts' );
add_action( 'admin_init', 'bambino_theme_add_editor_styles' );
add_action( 'admin_enqueue_scripts', 'bambino_load_fonts' );
add_action( 'admin_enqueue_scripts', 'bambino_load_admin_style' );

add_action( 'widgets_init', 'bambino_widget_area' );

add_filter( 'bt_bb_color_scheme_arr', 'bambino_color_schemes' );

add_filter( 'body_class', 'bambino_body_class' );

add_filter( 'tiny_mce_before_init', 'bambino_editor_dynamic_styles' );

add_theme_support( 'customize-selective-refresh-widgets' );

// callbacks

/**
 * Register navigation menus
 */
if ( ! function_exists( 'bambino_register_menus' ) ) {
	function bambino_register_menus() {
		register_nav_menus( array (
			'primary' => esc_html__( 'Primary Menu', 'bambino' ),
			'footer'  => esc_html__( 'Footer Menu', 'bambino' )
		));
	}
}

/**
 * Enqueue scripts and styles
 */
if ( ! function_exists( 'bambino_enqueue_scripts_styles' ) ) {
	function bambino_enqueue_scripts_styles() {
		
		BoldThemesFramework::$crush_vars_def = array( 'accentColor', 'alternateColor', 'thirdColor', 'fourthColor', 'bodyFont', 'menuFont', 'headingFont', 'headingSuperTitleFont', 'headingSubTitleFont', 'buttonFont', 'letterSpacingButton', 'letterSpacingSupertitle', 'logoHeight' );
		
		// Custom accent color and font style
		$boldthemes_add_override_css = false;		
		
		$accent_color = boldthemes_get_option( 'accent_color' );
		$alternate_color = boldthemes_get_option( 'alternate_color' );

		$third_color = boldthemes_get_option( 'third_color' );
		$fourth_color = boldthemes_get_option( 'fourth_color' );

		$body_font = urldecode( boldthemes_get_option( 'body_font' ) );
		$menu_font = urldecode( boldthemes_get_option( 'menu_font' ) );
		$heading_font = urldecode( boldthemes_get_option( 'heading_font' ) );
		$heading_supertitle_font = urldecode( boldthemes_get_option( 'heading_supertitle_font' ) );
		$heading_subtitle_font = urldecode( boldthemes_get_option( 'heading_subtitle_font' ) );
		$button_font = urldecode( boldthemes_get_option( 'button_font' ) );
		$logo_height = urldecode( boldthemes_get_option( 'logo_height' ) );
		$letter_spacing_button = urldecode( boldthemes_get_option( 'letter_spacing_button' ) );
		$letter_spacing_supertitle = urldecode( boldthemes_get_option( 'letter_spacing_supertitle' ) );

		if ( $accent_color != '' ) {
			BoldThemesFramework::$crush_vars['accentColor'] = $accent_color;
			if ( $accent_color != BoldThemes_Customize_Default::$data['accent_color'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $alternate_color != '' ) {
			BoldThemesFramework::$crush_vars['alternateColor'] = $alternate_color;
			if ( $alternate_color != BoldThemes_Customize_Default::$data['alternate_color'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $third_color != '' ) {
			BoldThemesFramework::$crush_vars['thirdColor'] = $third_color;
			if ( $third_color != BoldThemes_Customize_Default::$data['third_color'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $fourth_color != '' ) {
			BoldThemesFramework::$crush_vars['fourthColor'] = $fourth_color;
			if ( $fourth_color != BoldThemes_Customize_Default::$data['fourth_color'] ) {
				$boldthemes_add_override_css = true;
			}
		}


		if ( $body_font != '' ) {
			if ( $body_font == 'no_change' ) {
				$body_font = BoldThemes_Customize_Default::$data['body_font'];
			}
			BoldThemesFramework::$crush_vars['bodyFont'] = $body_font;
			if ( $body_font != BoldThemes_Customize_Default::$data['body_font'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $menu_font != '' ) {
			if ( $menu_font == 'no_change' ) {
				$menu_font = BoldThemes_Customize_Default::$data['menu_font'];
			}
			BoldThemesFramework::$crush_vars['menuFont'] = $menu_font;
			if ( $menu_font != BoldThemes_Customize_Default::$data['menu_font'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $heading_font != '' ) {
			if ( $heading_font == 'no_change' ) {
				$heading_font = BoldThemes_Customize_Default::$data['heading_font'];
			}
			BoldThemesFramework::$crush_vars['headingFont'] = $heading_font;
			if ( $heading_font != BoldThemes_Customize_Default::$data['heading_font'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $heading_supertitle_font != '' ) {
			if ( $heading_supertitle_font == 'no_change' ) {
				$heading_supertitle_font = BoldThemes_Customize_Default::$data['heading_supertitle_font'];
			}
			BoldThemesFramework::$crush_vars['headingSuperTitleFont'] = $heading_supertitle_font;
			if ( $heading_supertitle_font != BoldThemes_Customize_Default::$data['heading_supertitle_font'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $heading_subtitle_font != '' ) {
			if ( $heading_subtitle_font == 'no_change' ) {
				$heading_subtitle_font = BoldThemes_Customize_Default::$data['heading_subtitle_font'];
			}
			BoldThemesFramework::$crush_vars['headingSubTitleFont'] = $heading_subtitle_font;
			if ( $heading_subtitle_font != BoldThemes_Customize_Default::$data['heading_subtitle_font'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $button_font != '' ) {
			if ( $button_font == 'no_change' ) {
				$button_font = BoldThemes_Customize_Default::$data['button_font'];
			}
			BoldThemesFramework::$crush_vars['buttonFont'] = $button_font;
			if ( $button_font != BoldThemes_Customize_Default::$data['button_font'] ) {
				$boldthemes_add_override_css = true;
			}
		}
		
		if ( $logo_height != '' ) {
			BoldThemesFramework::$crush_vars['logoHeight'] = $logo_height;
			if ( $logo_height != BoldThemes_Customize_Default::$data['logo_height'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $letter_spacing_button != '' ) {
			BoldThemesFramework::$crush_vars['letterSpacingButton'] = $letter_spacing_button;
			if ( $letter_spacing_button != BoldThemes_Customize_Default::$data['letter_spacing_button'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		if ( $letter_spacing_supertitle != '' ) {
			BoldThemesFramework::$crush_vars['letterSpacingSupertitle'] = $letter_spacing_supertitle;
			if ( $letter_spacing_supertitle != BoldThemes_Customize_Default::$data['letter_spacing_supertitle'] ) {
				$boldthemes_add_override_css = true;
			}
		}

		// Create override file without local settings

		if ( function_exists( 'boldthemes_csscrush_file' ) ) {
			boldthemes_csscrush_file( get_theme_file_path( 'style.crush.css' ), array( 'source_map' => true, 'minify' => false, 'output_file' => 'style', 'formatter' => 'block', 'boilerplate' => false, 'vars' => BoldThemesFramework::$crush_vars, 'plugins' => array( 'loop', 'ease' ) ) );
		}

		// custom theme css
		wp_enqueue_style( 'bambino-style', get_parent_theme_file_uri( 'style.css' ), array(), false, 'screen' );
		wp_enqueue_style( 'bambino-print', get_parent_theme_file_uri( 'print.css' ), array(), false, 'print' );

		// external js
		wp_enqueue_script( 'fancySelect', get_parent_theme_file_uri( 'framework/js/fancySelect.js' ), array( 'jquery' ), '', true );

		// custom theme js
		wp_enqueue_script( 'bambino-header-misc', get_parent_theme_file_uri( 'framework/js/header.misc.js' ), array( 'jquery' ), '', true );
		wp_enqueue_script( 'bambino-misc', get_parent_theme_file_uri( 'framework/js/misc.js' ), array( 'jquery' ), '', true );
		
		wp_add_inline_script( 'bambino-header-misc', boldthemes_set_global_uri(), 'before' );
		
		if ( file_exists( get_parent_theme_file_path( 'css-override.php' ) ) && $boldthemes_add_override_css ) {
			require_once( get_parent_theme_file_path( 'css-override.php' ) );
			wp_add_inline_style( 'bambino-style', $css_override );
		}
		
		if ( file_exists( get_parent_theme_file_path( 'icons.php' ) ) ) {
			require_once( get_parent_theme_file_path( 'icons.php' ) );
			wp_add_inline_style( 'bambino-style', $icons );
		}

		if ( boldthemes_get_option( 'custom_js' ) != '' ) {
			wp_add_inline_script( 'bambino-misc', boldthemes_get_option( 'custom_js' ) );
		}	
		
	}
}

/**
 * Register the required plugins for this theme
 */
if ( ! function_exists( 'bambino_register_plugins' ) ) {
	function bambino_register_plugins() {

		$plugins = array(
	 
			array(
				'name'               => esc_html__( 'Bambino', 'bambino' ), // The plugin name.
				'slug'               => 'bambino', // The plugin slug (typically the folder name).
				'source'             => get_parent_theme_file_path( 'plugins/bambino.zip' ), // The plugin source.
				'required'           => true, // If false, the plugin is only 'recommended' instead of required.
				'version'            => '1.1.3', ///!do not change this comment! E.g. 1.0.0. If set, the active plugin must be this version or higher.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
				'external_url'       => '', // If set, overrides default API URL and points to an external URL.
			),
			array(
				'name'               => esc_html__( 'Cost Calculator', 'bambino' ), // The plugin name.
				'slug'               => 'bt' . '_cost_calculator', // The plugin slug (typically the folder name).
				'source'             => get_parent_theme_file_path( 'plugins/' . 'bt' . '_cost_calculator.zip' ), // The plugin source.
				'required'           => true, // If false, the plugin is only 'recommended' instead of required.
				'version'            => '3.0.4', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
				'external_url'       => '', // If set, overrides default API URL and points to an external URL.
			),
			array(
				'name'               => esc_html__( 'Bold Timeline Lite', 'bambino' ), // The plugin name.
				'slug'               => 'bold-timeline-lite', // The plugin slug (typically the folder name).
				'required'           => false, // If false, the plugin is only 'recommended' instead of required.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			),
			array(
				'name'               => esc_html__( 'AIKO: Instant Plugins AI Developer Lite', 'bambino' ), // The plugin name.
				'slug'               => 'aiko-developer-lite', // The plugin slug (typically the folder name).
				'required'           => false, // If false, the plugin is only 'recommended' instead of required.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			),
			array(
				'name'               => esc_html__( 'Bold Builder', 'bambino' ), // The plugin name.
				'slug'               => 'bold-page-builder', // The plugin slug (typically the folder name).
				'required'           => true, // If false, the plugin is only 'recommended' instead of required.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			),
			array(
				'name'               => esc_html__( 'BoldThemes WordPress Importer', 'bambino' ), // The plugin name.
				'slug'               => 'bt' . '_wordpress_importer', // The plugin slug (typically the folder name).
				'source'             => get_parent_theme_file_path( 'plugins/' . 'bt' . '_wordpress_importer.zip' ), // The plugin source.
				'required'           => true, // If false, the plugin is only 'recommended' instead of required.
				'version'            => '3.0.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
				'external_url'       => '', // If set, overrides default API URL and points to an external URL.
			),
			array(
				'name'               => esc_html__( 'Meta Box', 'bambino' ), // The plugin name.
				'slug'               => 'meta-box', // The plugin slug (typically the folder name).
				'required'           => true, // If false, the plugin is only 'recommended' instead of required.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			),
			array(
				'name'               => esc_html__( 'Contact Form 7', 'bambino' ), // The plugin name.
				'slug'               => 'contact-form-7', // The plugin slug (typically the folder name).
				'required'           => true, // If false, the plugin is only 'recommended' instead of required.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			),
			array(
				'name'               => esc_html__( 'Lightweight Sidebar Manager', 'bambino' ), // The plugin name.
				'slug'               => 'sidebar-manager', // The plugin slug (typically the folder name).
				'required'           => true, // If false, the plugin is only 'recommended' instead of required.
				'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
				'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			)
		);
	 
		$config = array(
			'default_path' => '',                      // Default absolute path to pre-packaged plugins.
			'menu'         => 'tgmpa-install-plugins', // Menu slug.
			'has_notices'  => true,                    // Show admin notices or not.
			'dismissable'  => false,                    // If false, a user cannot dismiss the nag message.
			'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
			'is_automatic' => false,                   // Automatically activate plugins after installation or not.
			'message'      => '',                      // Message to output right before the plugins table.
			'strings'      => array(
				'page_title'                      => esc_html__( 'Install Required Plugins', 'bambino' ),
				'menu_title'                      => esc_html__( 'Install Plugins', 'bambino' ),
				'installing'                      => esc_html__( 'Installing Plugin: %s', 'bambino' ), // %s = plugin name.
				'oops'                            => esc_html__( 'Something went wrong with the plugin API.', 'bambino' ),
				'notice_can_install_required'     => _n_noop( 'This theme requires the following plugin: %1$s.', 'This theme requires the following plugins: %1$s.', 'bambino' ), // %1$s = plugin name(s).
				'notice_can_install_recommended'  => _n_noop( 'This theme recommends the following plugin: %1$s.', 'This theme recommends the following plugins: %1$s.', 'bambino' ), // %1$s = plugin name(s).
				'notice_cannot_install'           => _n_noop( 'Sorry, but you do not have the correct permissions to install the %s plugin. Contact the administrator of this site for help on getting the plugin installed.', 'Sorry, but you do not have the correct permissions to install the %s plugins. Contact the administrator of this site for help on getting the plugins installed.', 'bambino' ), // %1$s = plugin name(s).
				'notice_can_activate_required'    => _n_noop( 'The following required plugin is currently inactive: %1$s.', 'The following required plugins are currently inactive: %1$s.', 'bambino' ), // %1$s = plugin name(s).
				'notice_can_activate_recommended' => _n_noop( 'The following recommended plugin is currently inactive: %1$s.', 'The following recommended plugins are currently inactive: %1$s.', 'bambino' ), // %1$s = plugin name(s).
				'notice_cannot_activate'          => _n_noop( 'Sorry, but you do not have the correct permissions to activate the %s plugin. Contact the administrator of this site for help on getting the plugin activated.', 'Sorry, but you do not have the correct permissions to activate the %s plugins. Contact the administrator of this site for help on getting the plugins activated.', 'bambino' ), // %1$s = plugin name(s).
				'notice_ask_to_update'            => _n_noop( 'The following plugin needs to be updated to its latest version to ensure maximum compatibility with this theme: %1$s.', 'The following plugins need to be updated to their latest version to ensure maximum compatibility with this theme: %1$s.', 'bambino' ), // %1$s = plugin name(s).
				'notice_cannot_update'            => _n_noop( 'Sorry, but you do not have the correct permissions to update the %s plugin. Contact the administrator of this site for help on getting the plugin updated.', 'Sorry, but you do not have the correct permissions to update the %s plugins. Contact the administrator of this site for help on getting the plugins updated.', 'bambino' ), // %1$s = plugin name(s).
				'install_link'                    => _n_noop( 'Begin installing plugin', 'Begin installing plugins', 'bambino' ),
				'activate_link'                   => _n_noop( 'Begin activating plugin', 'Begin activating plugins', 'bambino' ),
				'return'                          => esc_html__( 'Return to Required Plugins Installer', 'bambino' ),
				'plugin_activated'                => esc_html__( 'Plugin activated successfully.', 'bambino' ),
				'complete'                        => esc_html__( 'All plugins installed and activated successfully. %s', 'bambino' ), // %s = dashboard link.
				'nag_type'                        => 'updated' // Determines admin notice type - can only be 'updated', 'update-nag' or 'error'.
			)
		);
	 
		tgmpa( $plugins, $config );
	 
	}
}

/**
 * Loads custom Google Fonts
 */
if ( ! function_exists( 'bambino_load_fonts' ) ) {
	function bambino_load_fonts() {
		$body_font = urldecode( boldthemes_get_option( 'body_font' ) );
		$heading_font = urldecode( boldthemes_get_option( 'heading_font' ) );
		$menu_font = urldecode( boldthemes_get_option( 'menu_font' ) );
		$heading_subtitle_font = urldecode( boldthemes_get_option( 'heading_subtitle_font' ) );
		$heading_supertitle_font = urldecode( boldthemes_get_option( 'heading_supertitle_font' ) );
		$button_font = urldecode( boldthemes_get_option( 'button_font' ) );
		
		$font_families = array();
		
		if ( $body_font != '' ) {
			if ( $body_font == 'no_change' ) {
				$body_font = BoldThemes_Customize_Default::$data['body_font'];
			}
			$font_families[] = $body_font . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
		} else {
			/*
			Translators: If there are characters in your language that are not supported
			by chosen font(s), translate this to 'off'. Do not translate into your own language.
			 */
			if ( 'off' !== _x( 'on', 'Lato font: on or off', 'bambino' ) ) {
				$font_families[] = 'Lato' . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
			}
		}
		
		if ( $heading_font != '' ) {
			if ( $heading_font == 'no_change' ) {
				$heading_font = BoldThemes_Customize_Default::$data['heading_font'];
			}
			$font_families[] = $heading_font . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
		} else {
			/*
			Translators: If there are characters in your language that are not supported
			by chosen font(s), translate this to 'off'. Do not translate into your own language.
			 */
			if ( 'off' !== _x( 'on', 'Lato font: on or off', 'bambino' ) ) {
				$font_families[] = 'Lato' . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
			}
		}
		
		if ( $menu_font != '' ) {
			if ( $menu_font == 'no_change' ) {
				$menu_font = BoldThemes_Customize_Default::$data['menu_font'];
			}
			$font_families[] = $menu_font . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
		} else {
			/*
			Translators: If there are characters in your language that are not supported
			by chosen font(s), translate this to 'off'. Do not translate into your own language.
			 */
			if ( 'off' !== _x( 'on', 'Lato font: on or off', 'bambino' ) ) {
				$font_families[] = 'Lato' . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
			}
		}

		if ( $heading_subtitle_font != '' ) {
			if ( $heading_subtitle_font == 'no_change' ) {
				$heading_subtitle_font = BoldThemes_Customize_Default::$data['heading_subtitle_font'];
			}
			$font_families[] = $heading_subtitle_font . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
		} else {
			/*
			Translators: If there are characters in your language that are not supported
			by chosen font(s), translate this to 'off'. Do not translate into your own language.
			 */
			if ( 'off' !== _x( 'on', 'Lato font: on or off', 'bambino' ) ) {
				$font_families[] = 'Lato' . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
			}
		}

		if ( $heading_supertitle_font != '' ) {
			if ( $heading_supertitle_font == 'no_change' ) {
				$heading_supertitle_font = BoldThemes_Customize_Default::$data['heading_supertitle_font'];
			}
			$font_families[] = $heading_supertitle_font . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
		} else {
			/*
			Translators: If there are characters in your language that are not supported
			by chosen font(s), translate this to 'off'. Do not translate into your own language.
			 */
			if ( 'off' !== _x( 'on', 'Lato font: on or off', 'bambino' ) ) {
				$font_families[] = 'Lato' . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
			}
		}

		if ( $button_font != '' ) {
			if ( $button_font == 'no_change' ) {
				$button_font = BoldThemes_Customize_Default::$data['button_font'];
			}
			$font_families[] = $button_font . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
		} else {
			/*
			Translators: If there are characters in your language that are not supported
			by chosen font(s), translate this to 'off'. Do not translate into your own language.
			 */
			if ( 'off' !== _x( 'on', 'Lato font: on or off', 'bambino' ) ) {
				$font_families[] = 'Lato' . ':100,200,300,400,500,600,700,800,900,100italic,200italic,300italic,400italic,500italic,600italic,700italic,800italic,900italic';
			}
		}

		if ( count( $font_families ) > 0 ) {
			$query_args = array(
				'family' => urlencode( implode( '|', $font_families ) ),
				'subset' => urlencode( 'latin,latin-ext' ),
			);
			$font_url = add_query_arg( $query_args, 'https://fonts.googleapis.com/css' );
			wp_enqueue_style( 'bambino-fonts', $font_url, array(), '1.0.0' );
			add_editor_style( $font_url );
		}
	}
}

if ( ! function_exists( 'bambino_load_admin_style' ) ) {
	function bambino_load_admin_style() {
		if ( function_exists( 'boldthemes_csscrush_file' ) ) {
			boldthemes_csscrush_file( get_theme_file_path( 'admin-style.crush.css' ), array( 'source_map' => true, 'minify' => false, 'output_file' => 'admin-style', 'formatter' => 'block', 'boilerplate' => false, 'vars' => BoldThemesFramework::$crush_vars, 'plugins' => array( 'loop', 'ease' ) ) );
		}
		wp_enqueue_style( 'bambino-admin-style', get_parent_theme_file_uri( 'admin-style.css' ) );
		require_once( get_parent_theme_file_path( 'admin-style.php' ) );
		wp_add_inline_style( 'bambino-admin-style', $admin_style );
	}
}

/**
 * TinyMCE style
 */
if ( ! function_exists( 'bambino_theme_add_editor_styles' ) ) {
	function bambino_theme_add_editor_styles() {
	    add_editor_style( 'admin-style.css' );
	}
}

/** 
* Font 
*/

if ( ! function_exists( 'bt_bb_get_font_param_array' ) ) {
	function bt_bb_get_font_param_array() {
		require_once( dirname(__FILE__) . '/../../plugins/bold-page-builder/content_elements_misc/fonts.php' );
	}
}

/**
 * SVG Icon array
 */
if ( ! function_exists( 'bt_bb_get_svg_icons_param_array' ) ) {
	function bt_bb_get_svg_icons_param_array() {
	    return array(
			esc_html__( 'No icon', 'bambino' ) 					=> 'no_icon',

			esc_html__( 'Mail (Contact)', 'bambino' ) 			=> 'Contact/__Email',
			esc_html__( 'Hours (Contact)', 'bambino' ) 			=> 'Contact/__Hours',
			esc_html__( 'Location (Contact)', 'bambino' ) 		=> 'Contact/__Location',
			esc_html__( 'Mobile phone (Contact)', 'bambino' ) 	=> 'Contact/__Mobile_phone',
			esc_html__( 'Speech bubble (Contact)', 'bambino' ) 	=> 'Contact/__Speech_bubble',

			esc_html__( 'Face mask (Corona)', 'bambino' ) 		=> 'Corona/__Face_mask',
			esc_html__( 'Forbidden (Corona)', 'bambino' ) 		=> 'Corona/__Forbidden',
			esc_html__( 'Temperature (Corona)', 'bambino' ) 	=> 'Corona/__Temperature',
			esc_html__( 'Vaccine (Corona)', 'bambino' ) 		=> 'Corona/__Vaccine',

			esc_html__( 'Bell (Edu)', 'bambino' ) 				=> 'Edu/__Bell',
			esc_html__( 'Book (Edu)', 'bambino' ) 				=> 'Edu/__Book',
			esc_html__( 'Boy student (Edu)', 'bambino' ) 		=> 'Edu/__Boy_student',
			esc_html__( 'Brain (Edu)', 'bambino' ) 				=> 'Edu/__Brain',
			esc_html__( 'Calendar (Edu)', 'bambino' ) 			=> 'Edu/__Calendar',
			esc_html__( 'Certificate (Edu)', 'bambino' ) 		=> 'Edu/__Certificate',
			esc_html__( 'Color palette (Edu)', 'bambino' ) 		=> 'Edu/__Color_palette',
			esc_html__( 'Diploma (Edu)', 'bambino' ) 			=> 'Edu/__Diploma',
			esc_html__( 'E book (Edu)', 'bambino' ) 			=> 'Edu/__E_book',
			esc_html__( 'Girl student (Edu)', 'bambino' ) 		=> 'Edu/__Girl_student',
			esc_html__( 'Glasses (Edu)', 'bambino' ) 			=> 'Edu/__Glasses',
			esc_html__( 'Idea (Edu)', 'bambino' ) 				=> 'Edu/__Idea',
			esc_html__( 'Instructor (Edu)', 'bambino' ) 		=> 'Edu/__Instructor',
			esc_html__( 'Learn online (Edu)', 'bambino' ) 		=> 'Edu/__Learn_online',
			esc_html__( 'Notebook (Edu)', 'bambino' ) 			=> 'Edu/__Notebook',
			esc_html__( 'Notepad (Edu)', 'bambino' ) 			=> 'Edu/__Notepad',
			esc_html__( 'One book (Edu)', 'bambino' ) 			=> 'Edu/__One_book',
			esc_html__( 'Pencil (Edu)', 'bambino' ) 			=> 'Edu/__Pencil',
			esc_html__( 'School bag (Edu)', 'bambino' ) 		=> 'Edu/__School_bag',
			esc_html__( 'Table chair (Edu)', 'bambino' ) 		=> 'Edu/__Table_chair',
			esc_html__( 'Three books (Edu)', 'bambino' ) 		=> 'Edu/__Three_books',
			esc_html__( 'Two books (Edu)', 'bambino' ) 			=> 'Edu/__Two_books',
			esc_html__( '10 (Edu)', 'bambino' ) 				=> 'Edu/_-10',

			esc_html__( 'Apple (Food)', 'bambino' ) 			=> 'Food/__Apple',
			esc_html__( 'Apple carrot (Food)', 'bambino' ) 		=> 'Food/__Apple_carrot',
			esc_html__( 'Apricot (Food)', 'bambino' ) 			=> 'Food/__Apricot',
			esc_html__( 'Baby food (Food)', 'bambino' ) 		=> 'Food/__Baby_food',
			esc_html__( 'Banana (Food)', 'bambino' ) 			=> 'Food/__Banana',
			esc_html__( 'Bee (Food)', 'bambino' ) 				=> 'Food/__Bee',
			esc_html__( 'Bowl (Food)', 'bambino' ) 				=> 'Food/__Bowl',
			esc_html__( 'Broccoli (Food)', 'bambino' ) 			=> 'Food/__Broccoli',
			esc_html__( 'Carrot (Food)', 'bambino' ) 			=> 'Food/__Carrot',
			esc_html__( 'Certified (Food)', 'bambino' ) 		=> 'Food/__Certified',
			esc_html__( 'Cherry (Food)', 'bambino' ) 			=> 'Food/__Cherry',
			esc_html__( 'Corn (Food)', 'bambino' ) 				=> 'Food/__Corn',
			esc_html__( 'Eggplant (Food)', 'bambino' ) 			=> 'Food/__Eggplant',
			esc_html__( 'Fence (Food)', 'bambino' ) 			=> 'Food/__Fence',
			esc_html__( 'Fruit (Food)', 'bambino' ) 			=> 'Food/__Fruit',
			esc_html__( 'Growing plant (Food)', 'bambino' ) 	=> 'Food/__Growing_plant',
			esc_html__( 'Honey (Food)', 'bambino' ) 			=> 'Food/__Honey',
			esc_html__( 'Kiwi (Food)', 'bambino' ) 				=> 'Food/__Kiwi',
			esc_html__( 'Lettuce (Food)', 'bambino' ) 			=> 'Food/__Lettuce',
			esc_html__( 'No sugar (Food)', 'bambino' ) 			=> 'Food/__No_sugar',
			esc_html__( 'Non-GMO (Food)', 'bambino' ) 			=> 'Food/__Non-GMO',

			esc_html__( 'Organic (Food)', 'bambino' ) 			=> 'Food/__Organic',
			esc_html__( 'Pea (Food)', 'bambino' ) 				=> 'Food/__Pea',
			esc_html__( 'Pear (Food)', 'bambino' ) 				=> 'Food/__Pear',
			esc_html__( 'Pear apple (Food)', 'bambino' ) 		=> 'Food/__Pear_apple',
			esc_html__( 'Pineapple (Food)', 'bambino' ) 		=> 'Food/__Pineapple',
			esc_html__( 'Plums (Food)', 'bambino' ) 			=> 'Food/__Plums',
			esc_html__( 'Quince (Food)', 'bambino' ) 			=> 'Food/__Quince',
			esc_html__( 'Radish (Food)', 'bambino' ) 			=> 'Food/__Radish',
			esc_html__( 'Seed (Food)', 'bambino' ) 				=> 'Food/__Seed',
			esc_html__( 'Sprouts (Food)', 'bambino' ) 			=> 'Food/__Sprouts',
			esc_html__( 'Strawberry (Food)', 'bambino' ) 		=> 'Food/__Strawberry',
			esc_html__( 'Temperature (Food)', 'bambino' ) 		=> 'Food/__Temperature',
			esc_html__( 'Turnip (Food)', 'bambino' ) 			=> 'Food/__Turnip',
			esc_html__( 'Vegetable (Food)', 'bambino' ) 		=> 'Food/__Vegetable',
			esc_html__( 'Vegetable basket (Food)', 'bambino' ) 	=> 'Food/__Vegetable_basket',
			esc_html__( 'Water (Food)', 'bambino' ) 			=> 'Food/__Water',
			esc_html__( 'Wheat (Food)', 'bambino' ) 			=> 'Food/__Wheat',

			esc_html__( 'Abacus (Play)', 'bambino' ) 			=> 'Play/__Abacus',
			esc_html__( 'Baby (Play)', 'bambino' ) 				=> 'Play/__Baby',
			esc_html__( 'Baby bottle (Play)', 'bambino' ) 		=> 'Play/__Baby_bottle',
			esc_html__( 'Baby boy (Play)', 'bambino' ) 			=> 'Play/__Baby_boy',
			esc_html__( 'Baby clothes (Play)', 'bambino' ) 		=> 'Play/__Baby_clothes',
			esc_html__( 'Baby diaper (Play)', 'bambino' ) 		=> 'Play/__Baby_diaper',
			esc_html__( 'Baby shoes (Play)', 'bambino' ) 		=> 'Play/__Baby_shoes',
			esc_html__( 'Baby stroller (Play)', 'bambino' ) 	=> 'Play/__Baby_stroller',
			esc_html__( 'Backpack (Play)', 'bambino' ) 			=> 'Play/__Backpack',
			esc_html__( 'Ball (Play)', 'bambino' ) 				=> 'Play/__Ball',
			esc_html__( 'Balloon (Play)', 'bambino' ) 			=> 'Play/__Balloon',
			esc_html__( 'Basketball (Play)', 'bambino' ) 		=> 'Play/__Basketball',
			esc_html__( 'Bath (Play)', 'bambino' ) 				=> 'Play/__Bath',
			esc_html__( 'Bouncing castle (Play)', 'bambino' ) 	=> 'Play/__Bouncing_castle',
			esc_html__( 'Boy (Play)', 'bambino' ) 				=> 'Play/__Boy',
			esc_html__( 'Cake (Play)', 'bambino' ) 				=> 'Play/__Cake',
			esc_html__( 'Car toy 34 (Play)', 'bambino' ) 		=> 'Play/__Car_toy-34',
			esc_html__( 'Car toy 47 (Play)', 'bambino' ) 		=> 'Play/__Car_toy-47',
			esc_html__( 'Coffee (Play)', 'bambino' ) 			=> 'Play/__Coffee',
			esc_html__( 'Crayons (Play)', 'bambino' ) 			=> 'Play/__Crayons',
			esc_html__( 'Cutlery (Play)', 'bambino' ) 			=> 'Play/__Cutlery',
			esc_html__( 'Direction board (Play)', 'bambino' ) 	=> 'Play/__Direction_board',
			esc_html__( 'Football (Play)', 'bambino' ) 			=> 'Play/__Football',
			esc_html__( 'Gamepad (Play)', 'bambino' ) 			=> 'Play/__Gamepad',
			esc_html__( 'Gift box (Play)', 'bambino' ) 			=> 'Play/__Gift_box',
			esc_html__( 'Girl (Play)', 'bambino' ) 				=> 'Play/__Girl',
			esc_html__( 'Juice (Play)', 'bambino' ) 			=> 'Play/__Juice',
			esc_html__( 'Kite (Play)', 'bambino' ) 				=> 'Play/__Kite',
			esc_html__( 'Lollypop (Play)', 'bambino' ) 			=> 'Play/__Lollypop',
			esc_html__( 'Pacifier (Play)', 'bambino' ) 			=> 'Play/__Pacifier',
			esc_html__( 'Party (Play)', 'bambino' ) 			=> 'Play/__Party',
			esc_html__( 'Party hat (Play)', 'bambino' ) 		=> 'Play/__Party_hat',
			esc_html__( 'Pinwheel (Play)', 'bambino' ) 			=> 'Play/__Pinwheel',
			esc_html__( 'Playground (Play)', 'bambino' ) 		=> 'Play/__Playground',
			esc_html__( 'Playground 1 (Play)', 'bambino' ) 		=> 'Play/__Playground_1',
			esc_html__( 'Rattle (Play)', 'bambino' ) 			=> 'Play/__Rattle',
			esc_html__( 'Rattle toy (Play)', 'bambino' ) 		=> 'Play/__Rattle_toy',
			esc_html__( 'Rocket (Play)', 'bambino' ) 			=> 'Play/__Rocket',
			esc_html__( 'Sand bucket (Play)', 'bambino' ) 		=> 'Play/__Sand_bucket',
			esc_html__( 'Sandwitch (Play)', 'bambino' ) 		=> 'Play/__Sandwitch',
			esc_html__( 'School (Play)', 'bambino' ) 			=> 'Play/__School',
			esc_html__( 'Shoe (Play)', 'bambino' ) 				=> 'Play/__Shoe',
			esc_html__( 'Skipping rope (Play)', 'bambino' ) 	=> 'Play/__Skipping_rope',
			esc_html__( 'Socks (Play)', 'bambino' ) 			=> 'Play/__Socks',
			esc_html__( 'Spinning top (Play)', 'bambino' ) 		=> 'Play/__Spinning_top',
			esc_html__( 'Story (Play)', 'bambino' ) 			=> 'Play/__Story',
			esc_html__( 'Stroller (Play)', 'bambino' ) 			=> 'Play/__Stroller',
			esc_html__( 'Swing horse (Play)', 'bambino' ) 		=> 'Play/__Swing_horse',
			esc_html__( 'Sword toy (Play)', 'bambino' ) 		=> 'Play/__Sword_toy',
			esc_html__( 'Teddy bear (Play)', 'bambino' ) 		=> 'Play/__Teddy_bear',
			esc_html__( 'Train toy (Play)', 'bambino' ) 		=> 'Play/__Train_toy',
			esc_html__( 'Tricycle (Play)', 'bambino' ) 			=> 'Play/__Tricycle',
			esc_html__( 'Yoyo (Play)', 'bambino' ) 				=> 'Play/__Yoyo',

			esc_html__( 'Alarm (Bambino)', 'bambino' ) 			=> 'Bambino/__Alarm',
			esc_html__( 'Baby bottle (Bambino)', 'bambino' ) 	=> 'Bambino/__Baby_bottle',
			esc_html__( 'Baby clothes (Bambino)', 'bambino' ) 	=> 'Bambino/__Baby_clothes',
			esc_html__( 'Baby 01 (Bambino)', 'bambino' ) 		=> 'Bambino/__Baby_01',
			esc_html__( 'Baby 02 (Bambino)', 'bambino' ) 		=> 'Bambino/__Baby_02',
			esc_html__( 'Baby 03 (Bambino)', 'bambino' ) 		=> 'Bambino/__Baby_03',
			esc_html__( 'Bag (Bambino)', 'bambino' ) 			=> 'Bambino/__Bag',
			esc_html__( 'Balloons (Bambino)', 'bambino' ) 		=> 'Bambino/__Balloons',
			esc_html__( 'Bamboo (Bambino)', 'bambino' ) 		=> 'Bambino/__Bamboo',
			esc_html__( 'Basketball (Bambino)', 'bambino' ) 	=> 'Bambino/__Basketball',
			esc_html__( 'Bib (Bambino)', 'bambino' ) 			=> 'Bambino/__Bib',
			esc_html__( 'Book (Bambino)', 'bambino' ) 			=> 'Bambino/__Book',
			esc_html__( 'Boy (Bambino)', 'bambino' ) 			=> 'Bambino/__Boy',
			esc_html__( 'Brain (Bambino)', 'bambino' ) 			=> 'Bambino/__Brain',
			esc_html__( 'Cake (Bambino)', 'bambino' ) 			=> 'Bambino/__Cake',
			esc_html__( 'Calendar (Bambino)', 'bambino' ) 			=> 'Bambino/__Calendar',
			esc_html__( 'Camera (Bambino)', 'bambino' ) 			=> 'Bambino/__Camera',
			esc_html__( 'Cancel (Bambino)', 'bambino' ) 			=> 'Bambino/__Cancel',
			esc_html__( 'Care (Bambino)', 'bambino' ) 				=> 'Bambino/__Care',
			esc_html__( 'Certificate (Bambino)', 'bambino' ) 		=> 'Bambino/__Certificate',
			esc_html__( 'Checkmark (Bambino)', 'bambino' ) 			=> 'Bambino/__Checkmark',
			esc_html__( 'Clock (Bambino)', 'bambino' ) 				=> 'Bambino/__Clock',
			esc_html__( 'Computer (Bambino)', 'bambino' ) 			=> 'Bambino/__Computer',
			esc_html__( 'Crib (Bambino)', 'bambino' ) 				=> 'Bambino/__Crib',
			esc_html__( 'Cutlery (Bambino)', 'bambino' ) 			=> 'Bambino/__Cutlery',
			esc_html__( 'Diapers (Bambino)', 'bambino' ) 			=> 'Bambino/__Diapers',
			esc_html__( 'Diploma (Bambino)', 'bambino' ) 			=> 'Bambino/__Diploma',
			esc_html__( 'Eye (Bambino)', 'bambino' ) 				=> 'Bambino/__Eye',
			esc_html__( 'Facebook (Bambino)', 'bambino' ) 			=> 'Bambino/__Facebook',
			esc_html__( 'Facemask (Bambino)', 'bambino' ) 			=> 'Bambino/__Facemask',
			esc_html__( 'Files (Bambino)', 'bambino' ) 				=> 'Bambino/__Files',
			esc_html__( 'Gift (Bambino)', 'bambino' ) 				=> 'Bambino/__Gift',
			esc_html__( 'Girl (Bambino)', 'bambino' ) 				=> 'Bambino/__Girl',
			esc_html__( 'Glasses (Bambino)', 'bambino' ) 			=> 'Bambino/__Glasses',
			esc_html__( 'Goal (Bambino)', 'bambino' ) 				=> 'Bambino/__Goal',
			esc_html__( 'Goals (Bambino)', 'bambino' ) 				=> 'Bambino/__Goals',
			esc_html__( 'Instagram (Bambino)', 'bambino' ) 			=> 'Bambino/__Instagram',
			esc_html__( 'Joystick (Bambino)', 'bambino' ) 			=> 'Bambino/__Joystick',
			esc_html__( 'Laptop (Bambino)', 'bambino' ) 			=> 'Bambino/__Laptop',
			esc_html__( 'Letter (Bambino)', 'bambino' ) 			=> 'Bambino/__Letter',
			esc_html__( 'Lighthouse (Bambino)', 'bambino' ) 		=> 'Bambino/__Lighthouse',
			esc_html__( 'Lotus (Bambino)', 'bambino' ) 				=> 'Bambino/__Lotus',
			esc_html__( 'Love (Bambino)', 'bambino' ) 				=> 'Bambino/__Love',
			esc_html__( 'Mailbox (Bambino)', 'bambino' ) 			=> 'Bambino/__Mailbox',
			esc_html__( 'Medal (Bambino)', 'bambino' ) 				=> 'Bambino/__Medal',
			esc_html__( 'Message (Bambino)', 'bambino' ) 			=> 'Bambino/__Message',
			esc_html__( 'Mobile (Bambino)', 'bambino' ) 			=> 'Bambino/__Mobile',
			esc_html__( 'Month (Bambino)', 'bambino' ) 				=> 'Bambino/__Month',
			esc_html__( 'Notes (Bambino)', 'bambino' ) 				=> 'Bambino/__Notes',
			esc_html__( 'Pacifier (Bambino)', 'bambino' ) 			=> 'Bambino/__Pacifier',
			esc_html__( 'Patch (Bambino)', 'bambino' ) 				=> 'Bambino/__Patch',
			esc_html__( 'Pen (Bambino)', 'bambino' ) 				=> 'Bambino/__Pen',
			esc_html__( 'Pencil (Bambino)', 'bambino' ) 			=> 'Bambino/__Pencil',
			esc_html__( 'Pillow (Bambino)', 'bambino' ) 			=> 'Bambino/__Pillow',
			esc_html__( 'Phone (Bambino)', 'bambino' ) 				=> 'Bambino/__Phone',
			esc_html__( 'Pin (Bambino)', 'bambino' ) 				=> 'Bambino/__Pin',
			esc_html__( 'Plus (Bambino)', 'bambino' ) 				=> 'Bambino/__Plus',
			esc_html__( 'Pulse (Bambino)', 'bambino' ) 				=> 'Bambino/__Pulse',
			esc_html__( 'Rattle (Bambino)', 'bambino' ) 			=> 'Bambino/__Rattle',
			esc_html__( 'Relax (Bambino)', 'bambino' ) 				=> 'Bambino/__Relax',
			esc_html__( 'Road sign (Bambino)', 'bambino' ) 			=> 'Bambino/__Road sign',
			esc_html__( 'Sanitizer (Bambino)', 'bambino' ) 			=> 'Bambino/__Sanitizer',
			esc_html__( 'Search (Bambino)', 'bambino' ) 			=> 'Bambino/__Search',
			esc_html__( 'Share (Bambino)', 'bambino' ) 				=> 'Bambino/__Share',
			esc_html__( 'Shield (Bambino)', 'bambino' ) 			=> 'Bambino/__Shield',
			esc_html__( 'Sleep toys (Bambino)', 'bambino' ) 		=> 'Bambino/__Sleep_toys',
			esc_html__( 'Slippers (Bambino)', 'bambino' ) 			=> 'Bambino/__Slippers',
			esc_html__( 'Speech bubble (Bambino)', 'bambino' ) 		=> 'Bambino/__Speech_bubble',
			esc_html__( 'Star (Bambino)', 'bambino' ) 				=> 'Bambino/__Star',
			esc_html__( 'Stopwatch (Bambino)', 'bambino' ) 			=> 'Bambino/__Stopwatch',
			esc_html__( 'Student (Bambino)', 'bambino' ) 			=> 'Bambino/__Student',
			esc_html__( 'Study (Bambino)', 'bambino' ) 				=> 'Bambino/__Study',
			esc_html__( 'Swimming pool (Bambino)', 'bambino' ) 		=> 'Bambino/__Swimming_pool',
			esc_html__( 'Tea (Bambino)', 'bambino' ) 				=> 'Bambino/__Tea',
			esc_html__( 'Teddy bear (Bambino)', 'bambino' ) 		=> 'Bambino/__Teddy_bear',
			esc_html__( 'Temperature (Bambino)', 'bambino' ) 		=> 'Bambino/__Temperature',
			esc_html__( 'Tree (Bambino)', 'bambino' ) 				=> 'Bambino/__Tree',
			esc_html__( 'Trophy (Bambino)', 'bambino' ) 			=> 'Bambino/__Trophy',
			esc_html__( 'Twitter (Bambino)', 'bambino' ) 			=> 'Bambino/__Twitter',
			esc_html__( 'Vaccine (Bambino)', 'bambino' ) 			=> 'Bambino/__Vaccine',
			esc_html__( 'Valleyball (Bambino)', 'bambino' ) 		=> 'Bambino/__Valleyball',
			esc_html__( 'Wallet (Bambino)', 'bambino' ) 			=> 'Bambino/__Wallet',
			esc_html__( 'Web page (Bambino)', 'bambino' ) 			=> 'Bambino/__Web_page',
			esc_html__( 'Yoga mat (Bambino)', 'bambino' ) 			=> 'Bambino/__Yoga_mat',
			esc_html__( 'Yoga (Bambino)', 'bambino' ) 				=> 'Bambino/__Yoga'
		);
	}
}

/* Get icon HTML */

if ( ! function_exists( 'bt_bb_get_svg_icon_html' ) ) {
	function bt_bb_get_svg_icon_html( $icon ) {				
		ob_start();
		require( dirname(__FILE__) . '/bold-page-builder/content_elements_misc/svg/' . $icon . '.svg' );
		return ob_get_clean();							
	}	
}



/**
 * Add FontAwesome to TinyMCE editor
 */
if ( ! function_exists( 'bambino_editor_dynamic_styles' ) ) {
	function bambino_editor_dynamic_styles( $mceInit ) {
	    $styles = '@font-face{font-family:\"FontAwesome\";src:url(\"' . get_parent_theme_file_uri( 'fonts/FontAwesome/FontAwesome.woff' ) . '\") format(\"woff\"),url(\"' . get_parent_theme_file_uri( 'fonts/FontAwesome/FontAwesome.ttf' ) . '\") format(\"truetype\");}';
	    if ( isset( $mceInit['content_style'] ) ) {
	        $mceInit['content_style'] .= ' ' . ( $styles ) . ' ';
	    } else {
	        $mceInit['content_style'] = $styles . ' ';
	    }
	    return $mceInit;
	}
}

/**
 * Add class to body
 *
 * @return string 
 */
if ( ! function_exists( 'bambino_body_class' ) ) {
	function bambino_body_class( $extra_class ) {
		if ( boldthemes_get_option( 'default_heading_weight' ) ) {
			$extra_class[] =  'btHeadingWeight_' . boldthemes_get_option( 'default_heading_weight' );
		}
		if ( boldthemes_get_option( 'default_supertitle_weight' ) ) {
			$extra_class[] =  'btSupertitleWeight_' . boldthemes_get_option( 'default_supertitle_weight' );
		}
		if ( boldthemes_get_option( 'default_subtitle_weight' ) ) {
			$extra_class[] =  'btSubtitleWeight_' . boldthemes_get_option( 'default_subtitle_weight' );
		}
		if ( boldthemes_get_option( 'default_menu_weight' ) ) {
			$extra_class[] =  'btMenuWeight_' . boldthemes_get_option( 'default_menu_weight' );
		}
		if ( boldthemes_get_option( 'capitalize_main_menu' ) ) {
			$extra_class[] = 'btCapitalizeMainMenuItems';
		}
		if ( boldthemes_get_option( 'highlight_current_page' ) ) {
			$extra_class[] =  'btCurrentPage_' . boldthemes_get_option( 'highlight_current_page' );
		}
		if ( boldthemes_get_option( 'default_button_weight' ) ) {
			$extra_class[] =  'btButtonWeight_' . boldthemes_get_option( 'default_button_weight' );
		}
		if ( boldthemes_get_option( 'menu_font_size' ) ) {
			$extra_class[] =  'btMenuFontSize' . boldthemes_get_option( 'menu_font_size' );
		}
		if ( boldthemes_get_option( 'accent_button_dark_text' ) ) {
			$extra_class[] = 'btAccentButtonDarkText';
		}
		if ( boldthemes_get_option( 'text_color' ) ) {
			$extra_class[] =  'btTextColor_' . boldthemes_get_option( 'text_color' );
		}

		return $extra_class;
	}
}

/**
 * Shop sidebar
 */
if ( ! function_exists( 'bambino_widget_area' ) ) {
	function bambino_widget_area() {
		if ( class_exists( 'woocommerce' ) ) {
			register_sidebar( array (
				'name' 			=> esc_html__( 'Shop Sidebar', 'bambino' ),
				'id' 			=> 'bt_shop_sidebar',
				'description'   => 'WooCommerce sidebar',
				'before_widget' => '<div class="btBox %2$s">',
				'after_widget' 	=> '</div>',
				'before_title' 	=> '<h4><span>',
				'after_title' 	=> '</span></h4>',
			));
		}
	}
}

require_once( get_parent_theme_file_path( 'php/before_framework.php' ) );
require_once( get_parent_theme_file_path( 'framework/framework.php' ) );
require_once( get_parent_theme_file_path( 'php/config.php' ) );
require_once( get_parent_theme_file_path( 'php/after_framework.php' ) );